@@ -101,17 +101,12 @@ public final class DropboxFileStorageService extends AbstractOAuthFileStorageSer
     @Override
     public List<FileStoragePermission> getRootFolderPermissions(String accountId, Session session) throws OXException {
         DefaultFileStoragePermission permission = DefaultFileStoragePermission.newInstance();
-        permission.setAdmin(false);
+        permission.setAdmin(true);
         permission.setFolderPermission(FileStoragePermission.CREATE_SUB_FOLDERS);
         permission.setEntity(session.getUserId());
         return Collections.<FileStoragePermission> singletonList(permission);
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.file.storage.oauth.AbstractOAuthFileStorageService#getScope()
-     */
     @Override
     protected OAuthScope getScope() {
         return DropboxOAuthScope.drive;
